@@ -25,15 +25,13 @@ namespace spoa {
     class AlignmentEngine;
 }
 
-namespace logger {
-    class Logger;
-}
 
 namespace racon {
 
 class Sequence;
 class Overlap;
 class Window;
+class Logger;
 
 enum class PolisherType {
     kC, // Contig polishing
@@ -44,7 +42,7 @@ class Polisher;
 std::unique_ptr<Polisher> createPolisher(const std::string& sequences_path,
     const std::string& overlaps_path, const std::string& target_path,
     PolisherType type, uint32_t window_length, double quality_threshold,
-    double error_threshold, int8_t match, int8_t mismatch, int8_t gap,
+    double error_threshold, bool trim, int8_t match, int8_t mismatch, int8_t gap,
     uint32_t num_threads, uint32_t cuda_batches = 0,
     bool cuda_banded_alignment = false, uint32_t cudaaligner_batches = 0);
 
@@ -60,7 +58,7 @@ public:
     friend std::unique_ptr<Polisher> createPolisher(const std::string& sequences_path,
         const std::string& overlaps_path, const std::string& target_path,
         PolisherType type, uint32_t window_length, double quality_threshold,
-        double error_threshold, int8_t match, int8_t mismatch, int8_t gap,
+        double error_threshold, bool trim, int8_t match, int8_t mismatch, int8_t gap,
         uint32_t num_threads, uint32_t cuda_batches, bool cuda_banded_alignment,
         uint32_t cudaaligner_batches);
 
@@ -69,7 +67,7 @@ protected:
         std::unique_ptr<bioparser::Parser<Overlap>> oparser,
         std::unique_ptr<bioparser::Parser<Sequence>> tparser,
         PolisherType type, uint32_t window_length, double quality_threshold,
-        double error_threshold, int8_t match, int8_t mismatch, int8_t gap,
+        double error_threshold, bool trim, int8_t match, int8_t mismatch, int8_t gap,
         uint32_t num_threads);
     Polisher(const Polisher&) = delete;
     const Polisher& operator=(const Polisher&) = delete;
@@ -82,6 +80,7 @@ protected:
     PolisherType type_;
     double quality_threshold_;
     double error_threshold_;
+    bool trim_;
     std::vector<std::shared_ptr<spoa::AlignmentEngine>> alignment_engines_;
 
     std::vector<std::unique_ptr<Sequence>> sequences_;
@@ -94,7 +93,7 @@ protected:
     std::unique_ptr<thread_pool::ThreadPool> thread_pool_;
     std::unordered_map<std::thread::id, uint32_t> thread_to_id_;
 
-    std::unique_ptr<logger::Logger> logger_;
+    std::unique_ptr<Logger> logger_;
 };
 
 }
