@@ -29,11 +29,11 @@ public:
     void SetUp(const std::string& sequences_path, const std::string& overlaps_path,
         const std::string& target_path, racon::PolisherType type,
         uint32_t window_length, double quality_threshold, double error_threshold,
-        int8_t match,int8_t mismatch, int8_t gap, uint32_t cuda_batches = 0,
+        int8_t match, int8_t mismatch, int8_t gap, uint32_t cuda_batches = 0,
         bool cuda_banded_alignment = false, uint32_t cudaaligner_batches = 0) {
 
         polisher = racon::createPolisher(sequences_path, overlaps_path, target_path,
-            type, window_length, quality_threshold, error_threshold, match,
+            type, window_length, quality_threshold, error_threshold, true, match,
             mismatch, gap, 4, cuda_batches, cuda_banded_alignment, cudaaligner_batches);
     }
 
@@ -54,25 +54,25 @@ public:
 
 TEST(RaconInitializeTest, PolisherTypeError) {
     EXPECT_DEATH((racon::createPolisher("", "", "", static_cast<racon::PolisherType>(3),
-        0, 0, 0, 0, 0, 0, 0)), ".racon::createPolisher. error: invalid polisher"
+        0, 0, 0, 0, 0, 0, 0, 0)), ".racon::createPolisher. error: invalid polisher"
         " type!");
 }
 
 TEST(RaconInitializeTest, WindowLengthError) {
     EXPECT_DEATH((racon::createPolisher("", "", "", racon::PolisherType::kC, 0,
-        0, 0, 0, 0, 0, 0)), ".racon::createPolisher. error: invalid window length!");
+        0, 0, 0, 0, 0, 0, 0)), ".racon::createPolisher. error: invalid window length!");
 }
 
 TEST(RaconInitializeTest, SequencesPathExtensionError) {
     EXPECT_DEATH((racon::createPolisher("", "", "", racon::PolisherType::kC, 500,
-        0, 0, 0, 0, 0, 0)), ".racon::createPolisher. error: file  has unsupported "
-        "format extension .valid extensions: .fasta, .fasta.gz, .fa, .fa.gz, "
-        ".fastq, .fastq.gz, .fq, .fq.gz.!");
+        0, 0, 0, 0, 0, 0, 0)), ".racon::createPolisher. error: file  has unsupported "
+        "format extension .valid extensions: .fasta, .fasta.gz, .fna, .fna.gz, "
+        ".fa, .fa.gz, .fastq, .fastq.gz, .fq, .fq.gz.!");
 }
 
 TEST(RaconInitializeTest, OverlapsPathExtensionError) {
     EXPECT_DEATH((racon::createPolisher(racon_test_data_path + "sample_reads.fastq.gz",
-        "", "", racon::PolisherType::kC, 500, 0, 0, 0, 0, 0, 0)),
+        "", "", racon::PolisherType::kC, 500, 0, 0, 0, 0, 0, 0, 0)),
         ".racon::createPolisher. error: file  has unsupported format extension "
         ".valid extensions: .mhap, .mhap.gz, .paf, .paf.gz, .sam, .sam.gz.!");
 }
@@ -80,9 +80,9 @@ TEST(RaconInitializeTest, OverlapsPathExtensionError) {
 TEST(RaconInitializeTest, TargetPathExtensionError) {
     EXPECT_DEATH((racon::createPolisher(racon_test_data_path + "sample_reads.fastq.gz",
         racon_test_data_path + "sample_overlaps.paf.gz", "", racon::PolisherType::kC,
-        500, 0, 0, 0, 0, 0, 0)), ".racon::createPolisher. error: file  has "
-        "unsupported format extension .valid extensions: .fasta, .fasta.gz, .fa,"
-        " .fa.gz, .fastq, .fastq.gz, .fq, .fq.gz.!");
+        500, 0, 0, 0, 0, 0, 0, 0)), ".racon::createPolisher. error: file  has "
+        "unsupported format extension .valid extensions: .fasta, .fasta.gz, .fna, "
+        ".fna.gz, .fa, .fa.gz, .fastq, .fastq.gz, .fq, .fq.gz.!");
 }
 
 TEST_F(RaconPolishingTest, ConsensusWithQualities) {
@@ -491,6 +491,6 @@ TEST_F(RaconPolishingTest, FragmentCorrectionWithQualitiesFullMhapCUDA) {
     for (const auto& it: polished_sequences) {
         total_length += it->data().size();
     }
-    EXPECT_EQ(total_length, 1655505); // CPU 1658216 
+    EXPECT_EQ(total_length, 1655505); // CPU 1658216
 }
 #endif
